@@ -106,7 +106,9 @@ def test_tabular_algo(algo, output_dir, timeout, nan_fraction):
     fit_seconds = time.time() - t_start
 
     if fit_seconds > timeout:
-        raise TestError('timeout exceeded')
+        raise TestError(f'timeout exceeded by {fit_seconds - timeout} seconds')
+
+    print(f'Elapsed time: {fit_seconds}, timeout: {timeout}')
 
     test_tabular_predictor(model, output_dir, X, y)
 
